/*
 * Created on Jun 23, 2005
 *
 */
package com.octo.cas.client.websphere;

import java.util.Properties;

import javax.servlet.http.HttpServletRequest;

import com.ibm.websphere.security.TrustAssociationInterceptor;
import com.ibm.websphere.security.WebSphereBaseTrustAssociationInterceptor;
import com.ibm.websphere.security.WebTrustAssociationException;
import com.ibm.websphere.security.WebTrustAssociationFailedException;
import com.ibm.websphere.security.WebTrustAssociationUserException;

import edu.yale.its.tp.cas.client.ServiceTicketValidator;

/**
 * <a
 * href="http://www-306.ibm.com/software/webservers/appserv/doc/v40/ae/infocenter/was/050603.html">
 * Trusted Association Interceptor implementation for was 5.0.2</a> and CAS. <br/>This
 * TAI intercept calls containing the "ticket" parameter (Added by a CAS
 * server after successfull authentication), and check against a CAS server
 * that the ticket is valid for the requested service. <br/>It also uses this
 * ticket to retrieve the real user name information. <br/>
 * This implementation does not support the Proxy ticket mecanism
 * <br/>See static final properties of {@link CasTAIHelper} 
 * documentation for configuration.
 * 
 * 
 * 
 * @author Marc-Antoine Garrigue
 *  
 */
public class CasTAI502 extends WebSphereBaseTrustAssociationInterceptor implements TrustAssociationInterceptor {
	
	/* (non-Javadoc)
	 * @see com.ibm.websphere.security.WebSphereBaseTrustAssociationInterceptor#cleanup()
	 */
	public void cleanup() {


	}
	/* (non-Javadoc)
	 * @see com.ibm.websphere.security.WebSphereBaseTrustAssociationInterceptor#getType()
	 */
	public String getType() {
		return "CasTAI502";
	}
	/* (non-Javadoc)
	 * @see com.ibm.websphere.security.WebSphereBaseTrustAssociationInterceptor#getVersion()
	 */

	public String getVersion() {
		return "1.0.0";
	}
	/* (non-Javadoc)
	 * @see com.ibm.websphere.security.WebSphereBaseTrustAssociationInterceptor#init(java.util.Properties)
	 */
	public int init(Properties props) {
		return CasTAIHelper.initialize(props);
	}
	/* (non-Javadoc)
	 * @see com.ibm.websphere.security.TrustAssociationInterceptor#getAuthenticatedUsername(javax.servlet.http.HttpServletRequest)
	 */
	public String getAuthenticatedUsername(HttpServletRequest request)
			throws WebTrustAssociationUserException {

		String ticket;
		try {
			ticket = CasTAIHelper.getTicket(request);
		} catch (ServiceTicketLostException e) {
			throw new WebTrustAssociationUserException(e.getMessage());
		}
		ServiceTicketValidator sv = new ServiceTicketValidator();
		try {
			String uid =  CasTAIHelper.negotiateValidateandEstablishTrust(ticket,request,sv);
			System.out.println("CAS Authentication success, returned principal :  '"+uid+"'");
			return uid;
		} catch (CasException e1) {
			throw new WebTrustAssociationUserException(e1.getMessage());
		}
	}
	/* (non-Javadoc)
	 * @see com.ibm.websphere.security.TrustAssociationInterceptor#isTargetInterceptor(javax.servlet.http.HttpServletRequest)
	 */
	public boolean isTargetInterceptor(HttpServletRequest request)
			throws WebTrustAssociationException {
		return CasTAIHelper.isTargetInterceptor(request);
	}
	/* (non-Javadoc)
	 * @see com.ibm.websphere.security.TrustAssociationInterceptor#validateEstablishedTrust(javax.servlet.http.HttpServletRequest)
	 */
	public void validateEstablishedTrust(HttpServletRequest request)
			throws WebTrustAssociationFailedException {
		try {
			CasTAIHelper.getTicket(request);
		} catch (ServiceTicketLostException e) {
			throw new WebTrustAssociationFailedException(e.getMessage());
		}
		
	}
}