/*
 * Created on Aug 31, 2005
 *
 */
package com.octo.cas.client.websphere;

import java.util.Properties;

import com.octo.cas.client.websphere.CasTAIHelper;

import junit.framework.TestCase;

/**
 * @author Marc-Antoine Garrigue
 *
 */
public class CasTAITest extends TestCase {

	
	public void testInitializeDefaultProperties() {
		assertEquals(null,CasTAIHelper.CAS_CALLBACK_PROXY_URL);
		assertEquals("/CasProxyServlet",CasTAIHelper.CAS_CALLBACK_PROXY_SERVLET);
		assertEquals(null,CasTAIHelper.CAS_VALIDATION_URL);
		assertEquals(false,CasTAIHelper.DEBUG);
		assertEquals("",CasTAIHelper.PRINCIPAL_PREFIX);
		assertEquals("",CasTAIHelper.PRINCIPAL_SUFFIX);
		assertEquals("CAS_REALM",CasTAIHelper.CAS_REALM_NAME);
		
	}
	
	
	public void testFailedInitializeWithoutRequiredProperties() throws Exception{
		Properties props = new Properties();
		
		assertEquals(-1,CasTAIHelper.initialize(props));
		assertEquals(null,CasTAIHelper.CAS_CALLBACK_PROXY_URL);
		assertEquals("/CasProxyServlet",CasTAIHelper.CAS_CALLBACK_PROXY_SERVLET);
		assertEquals(null,CasTAIHelper.CAS_VALIDATION_URL);
		assertEquals(false,CasTAIHelper.STORE_PROXY_TICKET);
		assertEquals(false,CasTAIHelper.DEBUG);
		assertEquals("",CasTAIHelper.PRINCIPAL_PREFIX);
		assertEquals("",CasTAIHelper.PRINCIPAL_SUFFIX);
		assertEquals("CAS_REALM",CasTAIHelper.CAS_REALM_NAME);
	}
	
	
	public void testInitializeWithRequiredAndProxyProperties() throws Exception{
				
		Properties props = new Properties();
		
		
		props.put(CasTAIHelper.CAS_VALIDATION_URL_PROP,"validation");
		props.put(CasTAIHelper.CAS_CALLBACK_PROXY_URL_PROP,"proxy");
		props.put(CasTAIHelper.STORE_PROXY_TICKET_PROP,"true");
		
		
		assertEquals(0,CasTAIHelper.initialize(props));
		assertEquals("proxy",CasTAIHelper.CAS_CALLBACK_PROXY_URL);
		assertEquals("/CasProxyServlet",CasTAIHelper.CAS_CALLBACK_PROXY_SERVLET);
		assertEquals(true,CasTAIHelper.STORE_PROXY_TICKET);
		assertEquals("validation",CasTAIHelper.CAS_VALIDATION_URL);
		assertEquals(false,CasTAIHelper.DEBUG);
		assertEquals("",CasTAIHelper.PRINCIPAL_PREFIX);
		assertEquals("",CasTAIHelper.PRINCIPAL_SUFFIX);
		assertEquals("CAS_REALM",CasTAIHelper.CAS_REALM_NAME);
	}
	
	
	public void testFailedInitializeWithRequiredAndProxyWithoutURLProperties() throws Exception{
					
		Properties props = new Properties();
		
		props.put(CasTAIHelper.CAS_VALIDATION_URL_PROP,"validation");
		props.put(CasTAIHelper.STORE_PROXY_TICKET_PROP,"true");

		assertEquals(-1,CasTAIHelper.initialize(props));
		assertEquals(true,CasTAIHelper.STORE_PROXY_TICKET);
		assertEquals("/CasProxyServlet",CasTAIHelper.CAS_CALLBACK_PROXY_SERVLET);
		assertEquals(null,CasTAIHelper.CAS_CALLBACK_PROXY_URL);
		assertEquals("validation",CasTAIHelper.CAS_VALIDATION_URL);
		assertEquals(false,CasTAIHelper.DEBUG);
		assertEquals("",CasTAIHelper.PRINCIPAL_PREFIX);
		assertEquals("",CasTAIHelper.PRINCIPAL_SUFFIX);
		assertEquals("CAS_REALM",CasTAIHelper.CAS_REALM_NAME);
	}
		
	public void testFailedInitializeWithRequiredAndProxyWithoutServletProperties() throws Exception{
		
		Properties props = new Properties();
		
		props.put(CasTAIHelper.CAS_VALIDATION_URL_PROP,"validation");
		props.put(CasTAIHelper.STORE_PROXY_TICKET_PROP,"true");
		props.put(CasTAIHelper.CAS_CALLBACK_PROXY_SERVLET_PROP,"");
		props.put(CasTAIHelper.CAS_CALLBACK_PROXY_URL_PROP,"proxy");
		
		assertEquals(-1,CasTAIHelper.initialize(props));
		
		assertEquals(true,CasTAIHelper.STORE_PROXY_TICKET);
		assertEquals("",CasTAIHelper.CAS_CALLBACK_PROXY_SERVLET);
		assertEquals("proxy",CasTAIHelper.CAS_CALLBACK_PROXY_URL);
		assertEquals("validation",CasTAIHelper.CAS_VALIDATION_URL);
		assertEquals(false,CasTAIHelper.DEBUG);
		assertEquals("",CasTAIHelper.PRINCIPAL_PREFIX);
		assertEquals("",CasTAIHelper.PRINCIPAL_SUFFIX);
		assertEquals("CAS_REALM",CasTAIHelper.CAS_REALM_NAME);
	}
	
	public void testInitializeOptionalProperties() throws Exception{
		Properties props = new Properties();
		
		props.put(CasTAIHelper.CAS_VALIDATION_URL_PROP,"validation");
		props.put(CasTAIHelper.CAS_CALLBACK_PROXY_URL_PROP,"proxy");
		props.put(CasTAIHelper.CAS_REALM_NAME_PROP,"realm");
		props.put(CasTAIHelper.DEBUG_PROP,"true");
		props.put(CasTAIHelper.PRINCIPAL_PREFIX_PROP,"prefix");
		props.put(CasTAIHelper.PRINCIPAL_SUFFIX_PROP,"suffix");
		
		assertEquals(0,CasTAIHelper.initialize(props));
		assertEquals("proxy",CasTAIHelper.CAS_CALLBACK_PROXY_URL);
		assertEquals("validation",CasTAIHelper.CAS_VALIDATION_URL);
		assertEquals(true,CasTAIHelper.DEBUG);
		assertEquals("/CasProxyServlet",CasTAIHelper.CAS_CALLBACK_PROXY_SERVLET);
		assertEquals("prefix",CasTAIHelper.PRINCIPAL_PREFIX);
		assertEquals("suffix",CasTAIHelper.PRINCIPAL_SUFFIX);
		assertEquals("realm",CasTAIHelper.CAS_REALM_NAME);

		props.put(CasTAIHelper.DEBUG_PROP,"false");
		assertEquals(0,CasTAIHelper.initialize(props));
		assertEquals(false,CasTAIHelper.DEBUG);
		
		props.put(CasTAIHelper.DEBUG_PROP,"poeut");
		assertEquals(0,CasTAIHelper.initialize(props));
		assertEquals(false,CasTAIHelper.DEBUG);
		
		props.put(CasTAIHelper.STORE_PROXY_TICKET_PROP,"false");
		assertEquals(0,CasTAIHelper.initialize(props));
		assertEquals(false,CasTAIHelper.STORE_PROXY_TICKET);
		
		props.put(CasTAIHelper.STORE_PROXY_TICKET_PROP,"true");
		assertEquals(0,CasTAIHelper.initialize(props));
		assertEquals(true,CasTAIHelper.STORE_PROXY_TICKET);
		

		props.put(CasTAIHelper.DEBUG_PROP,"true");
		assertEquals(0,CasTAIHelper.initialize(props));
		assertEquals(true,CasTAIHelper.DEBUG);
		
	}
	
	

	

}
